@@ -2,16 +2,15 @@
 import argparse
 import errno
 import os
-import shutil
 import unittest
 
 import mock
 import six
 from six.moves import reload_module  # pylint: disable=import-error
 
-from certbot import compat
-from certbot import errors
 import certbot.tests.util as test_util
+from certbot import errors
+from certbot.compat import misc
 
 
 class RunScriptTest(unittest.TestCase):
@@ -88,7 +87,6 @@ class LockDirUntilExit(test_util.TempDirTestCase):
         import certbot.util
         reload_module(certbot.util)
 
-    @test_util.broken_on_windows
     @mock.patch('certbot.util.logger')
     @mock.patch('certbot.util.atexit_register')
     def test_it(self, mock_register, mock_logger):
@@ -100,11 +98,15 @@ class LockDirUntilExit(test_util.TempDirTestCase):
 
         self.assertEqual(mock_register.call_count, 1)
         registered_func = mock_register.call_args[0][0]
-        shutil.rmtree(subdir)
-        registered_func()  # exception not raised
-        # logger.debug is only called once because the second call
-        # to lock subdir was ignored because it was already locked
-        self.assertEqual(mock_logger.debug.call_count, 1)
+
+        from certbot import util
+        # Despite lock_dir_until_exit has been called twice to subdir, its lock should have been
+        # added only once. So we expect to have two lock references: for self.tempdir and subdir
+        self.assertTrue(len(util._LOCKS) == 2)  # pylint: disable=protected-access
+        registered_func()  # Exception should not be raised
+        # Logically, logger.debug, that would be invoked in case of unlock failure,
+        # should never been called.
+        self.assertEqual(mock_logger.debug.call_count, 0)
 
 
 class SetUpCoreDirTest(test_util.TempDirTestCase):
@@ -117,7 +119,7 @@ class SetUpCoreDirTest(test_util.TempDirTestCase):
     @mock.patch('certbot.util.lock_dir_until_exit')
     def test_success(self, mock_lock):
         new_dir = os.path.join(self.tempdir, 'new')
-        self._call(new_dir, 0o700, compat.os_geteuid(), False)
+        self._call(new_dir, 0o700, misc.os_geteuid(), False)
         self.assertTrue(os.path.exists(new_dir))
         self.assertEqual(mock_lock.call_count, 1)
 
@@ -125,7 +127,7 @@ class SetUpCoreDirTest(test_util.TempDirTestCase):
     def test_failure(self, mock_make_or_verify):
         mock_make_or_verify.side_effect = OSError
         self.assertRaises(errors.Error, self._call,
-                          self.tempdir, 0o700, compat.os_geteuid(), False)
+                          self.tempdir, 0o700, misc.os_geteuid(), False)
 
 
 class MakeOrVerifyDirTest(test_util.TempDirTestCase):
@@ -142,7 +144,7 @@ class MakeOrVerifyDirTest(test_util.TempDirTestCase):
         self.path = os.path.join(self.tempdir, "foo")
         os.mkdir(self.path, 0o600)
 
-        self.uid = compat.os_geteuid()
+        self.uid = misc.os_geteuid()
 
     def _call(self, directory, mode):
         from certbot.util import make_or_verify_dir
@@ -152,11 +154,11 @@ class MakeOrVerifyDirTest(test_util.TempDirTestCase):
         path = os.path.join(self.tempdir, "bar")
         self._call(path, 0o650)
         self.assertTrue(os.path.isdir(path))
-        self.assertTrue(compat.compare_file_modes(os.stat(path).st_mode, 0o650))
+        self.assertTrue(misc.compare_file_modes(os.stat(path).st_mode, 0o650))
 
     def test_existing_correct_mode_does_not_fail(self):
         self._call(self.path, 0o600)
-        self.assertTrue(compat.compare_file_modes(os.stat(self.path).st_mode, 0o600))
+        self.assertTrue(misc.compare_file_modes(os.stat(self.path).st_mode, 0o600))
 
     @test_util.skip_on_windows('Umask modes are mostly ignored on Windows.')
     def test_existing_wrong_mode_fails(self):
@@ -179,7 +181,7 @@ class CheckPermissionsTest(test_util.TempDirTestCase):
     def setUp(self):
         super(CheckPermissionsTest, self).setUp()
 
-        self.uid = compat.os_geteuid()
+        self.uid = misc.os_geteuid()
 
     def _call(self, mode):
         from certbot.util import check_permissions
@@ -191,7 +193,12 @@ class CheckPermissionsTest(test_util.TempDirTestCase):
 
     def test_wrong_mode(self):
         os.chmod(self.tempdir, 0o400)
-        self.assertFalse(self._call(0o600))
+        try:
+            self.assertFalse(self._call(0o600))
+        finally:
+            # Without proper write permissions, Windows is unable to delete a folder,
+            # even with admin permissions. Write access must be explicitly set first.
+            os.chmod(self.tempdir, 0o700)
 
 
 class UniqueFileTest(test_util.TempDirTestCase):
@@ -216,8 +223,8 @@ class UniqueFileTest(test_util.TempDirTestCase):
     def test_right_mode(self):
         fd1, name1 = self._call(0o700)
         fd2, name2 = self._call(0o600)
-        self.assertTrue(compat.compare_file_modes(0o700, os.stat(name1).st_mode))
-        self.assertTrue(compat.compare_file_modes(0o600, os.stat(name2).st_mode))
+        self.assertTrue(misc.compare_file_modes(0o700, os.stat(name1).st_mode))
+        self.assertTrue(misc.compare_file_modes(0o600, os.stat(name2).st_mode))
         fd1.close()
         fd2.close()
 
@@ -277,20 +284,9 @@ class UniqueLineageNameTest(test_util.TempDirTestCase):
         for f, _ in items:
             f.close()
 
-    @mock.patch("certbot.util.os.fdopen")
-    def test_failure(self, mock_fdopen):
-        err = OSError("whoops")
-        err.errno = errno.EIO
-        mock_fdopen.side_effect = err
-        self.assertRaises(OSError, self._call, "wow")
-
-    @mock.patch("certbot.util.os.fdopen")
-    def test_subsequent_failure(self, mock_fdopen):
-        self._call("wow")
-        err = OSError("whoops")
-        err.errno = errno.EIO
-        mock_fdopen.side_effect = err
-        self.assertRaises(OSError, self._call, "wow")
+    def test_failure(self):
+        with mock.patch("certbot.util.os.open", side_effect=OSError(errno.EIO)):
+            self.assertRaises(OSError, self._call, "wow")
 
 
 class SafelyRemoveTest(test_util.TempDirTestCase):
@@ -355,29 +351,28 @@ class AddDeprecatedArgumentTest(unittest.TestCase):
 
     def _call(self, argument_name, nargs):
         from certbot.util import add_deprecated_argument
-
         add_deprecated_argument(self.parser.add_argument, argument_name, nargs)
 
     def test_warning_no_arg(self):
         self._call("--old-option", 0)
-        stderr = self._get_argparse_warnings(["--old-option"])
-        self.assertTrue("--old-option is deprecated" in stderr)
+        with mock.patch("certbot.util.logger.warning") as mock_warn:
+            self.parser.parse_args(["--old-option"])
+        self.assertEqual(mock_warn.call_count, 1)
+        self.assertTrue("is deprecated" in mock_warn.call_args[0][0])
+        self.assertEqual("--old-option", mock_warn.call_args[0][1])
 
     def test_warning_with_arg(self):
         self._call("--old-option", 1)
-        stderr = self._get_argparse_warnings(["--old-option", "42"])
-        self.assertTrue("--old-option is deprecated" in stderr)
-
-    def _get_argparse_warnings(self, args):
-        stderr = six.StringIO()
-        with mock.patch("certbot.util.sys.stderr", new=stderr):
-            self.parser.parse_args(args)
-        return stderr.getvalue()
+        with mock.patch("certbot.util.logger.warning") as mock_warn:
+            self.parser.parse_args(["--old-option", "42"])
+        self.assertEqual(mock_warn.call_count, 1)
+        self.assertTrue("is deprecated" in mock_warn.call_args[0][0])
+        self.assertEqual("--old-option", mock_warn.call_args[0][1])
 
     def test_help(self):
         self._call("--old-option", 2)
         stdout = six.StringIO()
-        with mock.patch("certbot.util.sys.stdout", new=stdout):
+        with mock.patch("sys.stdout", new=stdout):
             try:
                 self.parser.parse_args(["-h"])
             except SystemExit:
